@@ -1,14 +1,15 @@
 package Finance::Bank::ID::BPRKS;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.04'; # VERSION
+
 use 5.010001;
 use Moo;
 use DateTime;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.03'; # VERSION
-
 extends 'Finance::Bank::ID::Base';
 
 has _variant => (is => 'rw'); # 'individual' only, for now
@@ -449,7 +450,7 @@ Finance::Bank::ID::BPRKS - Check your BPR KS accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.03 of Finance::Bank::ID::BPRKS (from Perl distribution Finance-Bank-ID-BPRKS), released on 2015-04-28.
+This document describes version 0.04 of Finance::Bank::ID::BPRKS (from Perl distribution Finance-Bank-ID-BPRKS), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -733,7 +734,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BPRKS>.
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BPRKS>.
 
 =head1 BUGS
 
